@@ -57,6 +57,7 @@ class SerialProcessor:
         self.buffer_length = 15
         self.state = 'Idle'
         self.work_offsets = (0, 0, 0, 0)
+
         self.close_port = threading.Event()
         self.commandInvalid = threading.Event()
         self.serialReadUnlocked = threading.Event()
@@ -102,7 +103,7 @@ class SerialProcessor:
         if self._port is None:
             self.esp = None
         elif self._port == 'testing':
-            print('Connecting to dummy serial port')
+            self.controller.logger.debug('CONNECTING TO SERIAL PORT EMULATOR!!!')
             self.esp = DummySerial(port=port, baudrate=115200, timeout=1)
             self.start_threads()
         else:
@@ -110,8 +111,10 @@ class SerialProcessor:
                 self.esp = serial.Serial(port=self._port, baudrate=115200, timeout=1)
             except serial.SerialException:  # wrong port selected
                 self._port = None
+                self.controller.logger.debug('Failed to connect to serial port')
                 raise
             else:
+                self.controller.logger.debug(f'Successfully connected to serial port: {self.port}')
                 self.start_threads()
 
     def start_threads(self):
@@ -127,7 +130,7 @@ class SerialProcessor:
 
     def serialListen(self):
         """The event loop for the thread that reads messages from the serial port."""
-        print("Starting serial listener")
+        self.controller.logger.debug("Starting serial listener")
         while not self.close_port.is_set():
             if self.serialReadUnlocked.wait(timeout=0.5) and self.esp.in_waiting:
                 self.serialReadUnlocked.clear()
@@ -142,23 +145,23 @@ class SerialProcessor:
                     if not data:
                         continue
                     else:
-                        print(data)
+                        self.controller.logger.debug(data)
                 except Exception:
                     pass
                 self.serialReadUnlocked.set()
             time.sleep(0.01)
 
-        print("Stopping serial listener")
+        self.controller.logger.debug("Stopping serial listener")
         self.esp.flush()
         self.esp.close()
         try:
             self.controller.gui.sBut["state"] = "disabled"
         except Exception:
-            print("Window appears to be closed")
+            self.controller.logger.debug("Window appears to be closed")
 
     def serialReporter(self):
         """The event loop for the thread that sends messages to the serial port."""
-        print("Starting serial reporter")
+        self.controller.logger.debug("Starting serial reporter")
         while self.esp.is_open:
             if len(self.espBuffer) > 0:
                 for i, (bufferValue, wait_in_queue) in enumerate(
@@ -254,12 +257,15 @@ class SerialProcessor:
         work_position = None
         buffer_length = None
         total_message = message.decode().split('|')
+        feed_speed = None
+        spindle_speed = None
         if len(total_message) < 2:  # accidently received b'ok'
             return
         # message is sent as
         # b'<state|machine positions: x, y, z, a|BF:buffer size|FS:?,?|Work positions(optional):x,y,z,a>'
         total_message[0] = total_message[0].lstrip('<')
         total_message[-1] = total_message[-1].rstrip('>')
+        old_state = self.state
         for entry in total_message:
             if ':' not in entry:
                 self.state = entry
@@ -268,7 +274,7 @@ class SerialProcessor:
                 try:
                     header, values = entry.split(':')
                 except ValueError:  # message has multiple : at startup
-                    print(f'Encountered parsing error from: {entry}')
+                    self.controller.logger.debug(f'Encountered parsing error from: {entry}')
                     break
                 if header == 'MPos':
                     machine_position = [float(val) for val in values.split(',')]
@@ -276,6 +282,10 @@ class SerialProcessor:
                     work_position = [float(val) for val in values.split(',')]
                 elif header == 'Bf':
                     buffer_length = int(values.split(',')[0])
+                elif header == 'Ov':  # typically Ov:100,100,100
+                    # override values for feed (G1,G2,G3 motion), rapid (G0 motion), and spindle
+                    # in percentages
+                    feed_speed, _, spindle_speed = [int(val) for val in values.split(',')]
         # print(message.decode())
         if machine_position is not None:
             machine_x = machine_position[0]
@@ -316,6 +326,17 @@ class SerialProcessor:
             self.controller.gui.bufferVar.set(buffer_length)
             self.buffer_length = buffer_length
 
+        if old_state != self.state:
+            if old_state == 'Alarm':
+                self.controller.gui.resetBut.configure(fg="grey", state='disabled')
+            elif self.state == 'Alarm':
+                self.controller.gui.resetBut.configure(fg='black', state='normal')
+
+        if feed_speed is not None:
+            self.controller.gui.feed_var.set(f'{feed_speed}%')
+            self.controller.gui.spindle_var.set(f'{spindle_speed}%')
+
+
         self.controller.gui.stateVar.set(self.state)
         self.state_exact.set()
 
@@ -377,8 +398,8 @@ class SerialProcessor:
         """
         self.espBuffer.append(code)
         self.espTypeBuffer.append(wait_in_queue)
-        print(f'added to buffer: {code}')
-        print(f'internal buffer: {len(self.espBuffer)}')
+        self.controller.logger.debug(f'added to buffer: {code}')
+        self.controller.logger.debug(f'internal buffer: {len(self.espBuffer)}')
 
 
 class DummySerial:
@@ -400,6 +421,8 @@ class DummySerial:
         self.outputs = deque()
         self.machine_position = (0, 0, 0, 0)
         self.offsets = (0, 0, 0, 0)
+        # speeds for feed (G1,G2,G3 motion), rapid (G0 motion), and spindle
+        self.speeds = [100, 100, 100]
 
         self._read_thread = threading.Thread(target=self.main_loop, daemon=True)
         self._read_thread.start()
@@ -411,8 +434,12 @@ class DummySerial:
                 message_bytes = self.inputs.popleft()
                 try:
                     message = message_bytes.decode().strip('\n')
-                except UnicodeDecodeError:  # probably b'\x85'
-                    message = 'cancel jog'
+                except UnicodeDecodeError:
+                    if message_bytes == b'\x85':
+                        message = 'cancel jog'
+                    else:
+                        message = message_bytes.hex()
+
                 if not message:
                     continue
 
@@ -421,7 +448,7 @@ class DummySerial:
                     print(f'Serial emulator received: {message_bytes}')
 
                 if self.state == 'Alarm':
-                    if not (message.startswith('$H') or message in ('X', '?')):
+                    if not (message.startswith('$H') or message in ('$X', '?')):
                         continue
                     elif message != '?':
                         self.state = 'Idle'
@@ -443,6 +470,22 @@ class DummySerial:
                             self.state = 'Other'
                     else:
                         output = b'error:9'
+                elif message == '91':  # b'\x91' increase feed rate by 10%
+                    self.speeds[0] += 10
+                elif message == '92':  # b'\x92' decrease feed rate by 10%
+                    self.speeds[0] -= 10
+                elif message == '93':  # b'\x93' increase feed rate by 1%
+                    self.speeds[0] += 1
+                elif message == '94':  # b'\x94' decrease feed rate by 1%
+                    self.speeds[0] -= 1
+                elif message == '9a':  # b'\x9A' increase spindle rate by 10%
+                    self.speeds[2] += 10
+                elif message == '9b':  # b'\x9B' decrease spindle rate by 10%
+                    self.speeds[2] -= 10
+                elif message == '9c':  # b'\x9C' increase spindle rate by 1%
+                    self.speeds[2] += 1
+                elif message == '9d':  # b'\x9D' decrease spindle rate by 1%
+                    self.speeds[2] -= 1
                 elif message == '?':
                     if self.state not in ('Idle', 'Alarm'):
                         self.machine_position = (
@@ -457,8 +500,13 @@ class DummySerial:
                         )
                     output = f'<{self.state}|MPos:{self.machine_position[0]:.3f},{self.machine_position[1]:.3f},{self.machine_position[2]:.3f},{self.machine_position[3]:.3f}|Bf:{self.buffer},127|FS:0,0>'
                     if random.choice([0, 0, 0, 1]):
-                        output = output[:-1] + f'|WCO:{self.offsets[0]:.3f},{self.offsets[1]:.3f},{self.offsets[2]:.3f},{self.offsets[3]:.3f}'
+                        output = output[:-1] + f'|WCO:{self.offsets[0]:.3f},{self.offsets[1]:.3f},{self.offsets[2]:.3f},{self.offsets[3]:.3f}>'
+                    elif random.choice([0, 0, 0, 1]):
+                        output = output[:-1] + f'|Ov:{self.speeds[0]},{self.speeds[1]},{self.speeds[2]}>'
                     output = output.encode()
+                elif message.lower() == 'alarm':
+                    self.state = 'Alarm'
+                    output = b'Setting into alarm state'
 
                 self.outputs.append(output)
                 if self.state not in ('Idle', 'Jog', 'Alarm'):
